Index: trunk/psLib/src/xml/psXML.h
===================================================================
--- trunk/psLib/src/xml/psXML.h	(revision 1973)
+++ trunk/psLib/src/xml/psXML.h	(revision 2204)
@@ -9,6 +9,6 @@
 *  @author Ross Harman, MHPCC
 *
-*  @version $Revision: 1.1 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2004-10-06 01:17:39 $
+*  @version $Revision: 1.2 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2004-10-27 00:57:30 $
 *
 *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -50,5 +50,5 @@
     psMetadata* output,                ///< Resulting metadata from read.
     char *extName,                     ///< File name extension string.
-    int extNum,                        ///< File name extension number. Starts at 1.
+    psS32 extNum,                        ///< File name extension number. Starts at 1.
     char *fileName                     ///< Name of file to read.
 );
@@ -58,10 +58,10 @@
  *  Loads pre-defined settings by parsing a configuration file into a psMetadata structure.
  *
  *  @return int : Number of lines that failed to be read.
  */
-int psMetadataParseConfig(
+psS32 psMetadataParseConfig(
     psMetadata** md,                   ///< Resulting metadata from read.
     char *fileName,                    ///< Name of file to read.
-    bool overwrite                     ///< Allow overwrite of duplicate specifications.
+    psBool overwrite                     ///< Allow overwrite of duplicate specifications.
 );
 
@@ -58,10 +58,10 @@
  *  Loads pre-defined settings by parsing a configuration file into a psMetadata structure.
  *
- *  @return int : Number of lines that failed to be read.
+ *  @return psS32 : Number of lines that failed to be read.
  */
